def test_one_file_values(one_file_modifications_converted):
    edge = one_file_modifications_converted[0]
    assert edge.added == 8
    assert edge.deleted == 4
    assert edge.churn == 4
    assert edge.ratio == 50.0
    assert edge.churn_ratio == 50.0


def test_multiple_files_values(multiple_files_modifications_converted):
    file1, file2, file3 = multiple_files_modifications_converted
    # ---
    assert file1.added == 3
    assert file1.deleted == 1
    assert file1.churn == 0
    # ---
    assert file2.added == 1
    assert file2.deleted == 1
    assert file2.churn == 1
    # ---
    assert file3.added == 4
    assert file3.deleted == 2
    assert file3.churn == 2



import pytest
from datetime import datetime

from smyg import utils


@pytest.mark.freeze_time('2023-02-13')
@pytest.mark.parametrize(
        'past, past_date',
        [
            ('13d', datetime(2023, 1, 31)),
            ('12d', datetime(2023, 2, 1)),
            ('3m', datetime(2022, 11, 13)),
            ('1y', datetime(2022, 2, 13)),
            ]
        )
def test_date_from_relative(past, past_date):
    assert utils.date_from_relative(past) == past_date


def test_convert_to_edge_one(one_file_modifications):
    edge_files = utils.convert_to_edge(one_file_modifications)
    assert len(edge_files) == 1


def test_convert_to_edge_multiple(multiple_files_modifications):
    edge_files = utils.convert_to_edge(multiple_files_modifications)
    assert len(edge_files) == 3
